@@ -300,7 +300,8 @@ int readHB_header(FILE* in_file, char* Title, char* Key, char* Type,
     char line[BUFSIZ];
 
 /*  First line:   */
-    fgets(line, BUFSIZ, in_file);
+    if ( fgets(line, BUFSIZ, in_file) )
+	IOHBTerminate("iohb.c: Error in input\n");
     if ( sscanf(line,"%*s") < 0 )
         IOHBTerminate("iohb.c: Null (or blank) first line of HB file.\n");
     (void) sscanf(line, "%72c%8[^\n]", Title, Key);
@@ -308,7 +309,8 @@ int readHB_header(FILE* in_file, char* Title, char* Key, char* Type,
     *(Title+72) = '\0';
 
 /*  Second line:  */
-    fgets(line, BUFSIZ, in_file);
+    if ( fgets(line, BUFSIZ, in_file) )
+	IOHBTerminate("iohb.c: Error in input\n");
     if ( sscanf(line,"%*s") < 0 )
         IOHBTerminate("iohb.c: Null (or blank) second line of HB file.\n");
     if ( sscanf(line,"%i",&Totcrd) != 1) Totcrd = 0;
@@ -318,7 +320,8 @@ int readHB_header(FILE* in_file, char* Title, char* Key, char* Type,
     if ( sscanf(line,"%*i%*i%*i%*i%i",Rhscrd) != 1) *Rhscrd = 0;
 
 /*  Third line:   */
-    fgets(line, BUFSIZ, in_file);
+    if ( fgets(line, BUFSIZ, in_file) )
+	IOHBTerminate("iohb.c: Error in input\n");
     if ( sscanf(line,"%*s") < 0 )
         IOHBTerminate("iohb.c: Null (or blank) third line of HB file.\n");
     if ( sscanf(line, "%3c", Type) != 1)
@@ -330,7 +333,8 @@ int readHB_header(FILE* in_file, char* Title, char* Key, char* Type,
     if ( sscanf(line,"%*3c%*i%*i%*i%i",&Neltvl) != 1) Neltvl = 0 ;
 
 /*  Fourth line:  */
-    fgets(line, BUFSIZ, in_file);
+    if ( fgets(line, BUFSIZ, in_file) )
+	IOHBTerminate("iohb.c: Error in input\n");
     if ( sscanf(line,"%*s") < 0 )
         IOHBTerminate("iohb.c: Null (or blank) fourth line of HB file.\n");
     if ( sscanf(line, "%16c",Ptrfmt) != 1)
@@ -348,7 +352,8 @@ int readHB_header(FILE* in_file, char* Title, char* Key, char* Type,
 /*  (Optional) Fifth line: */
     if (*Rhscrd != 0 )
     {
-       fgets(line, BUFSIZ, in_file);
+	if ( fgets(line, BUFSIZ, in_file) )
+	     IOHBTerminate("iohb.c: Error in input\n");
        if ( sscanf(line,"%*s") < 0 )
            IOHBTerminate("iohb.c: Null (or blank) fifth line of HB file.\n");
        if ( sscanf(line, "%3c", Rhstype) != 1)
@@ -421,7 +426,8 @@ int readHB_mat_double(const char* filename, int colptr[], int rowind[],
     count=0;
     for (i=0;i<Ptrcrd;i++)
     {
-       fgets(line, BUFSIZ, in_file);
+	if ( fgets(line, BUFSIZ, in_file) )
+	    IOHBTerminate("iohb.c: Error in input\n");
        if ( sscanf(line,"%*s") < 0 )
          IOHBTerminate("iohb.c: Null (or blank) line in pointer data region of HB file.\n");
        col =  0;
@@ -444,7 +450,8 @@ int readHB_mat_double(const char* filename, int colptr[], int rowind[],
     count = 0;
     for (i=0;i<Indcrd;i++)
     {
-       fgets(line, BUFSIZ, in_file);
+	if ( fgets(line, BUFSIZ, in_file) )
+	     IOHBTerminate("iohb.c: Error in input\n");
        if ( sscanf(line,"%*s") < 0 )
          IOHBTerminate("iohb.c: Null (or blank) line in index data region of HB file.\n");
        col =  0;
@@ -473,7 +480,8 @@ int readHB_mat_double(const char* filename, int colptr[], int rowind[],
     count = 0;
     for (i=0;i<Valcrd;i++)
     {
-       fgets(line, BUFSIZ, in_file);
+	if ( fgets(line, BUFSIZ, in_file) ) 
+	     IOHBTerminate("iohb.c: Error in input\n");
        if ( sscanf(line,"%*s") < 0 )
          IOHBTerminate("iohb.c: Null (or blank) line in value data region of HB file.\n");
        if (Valflag == 'D')  {
@@ -624,7 +632,8 @@ int readHB_aux_double(const char* filename, const char AuxType, double b[])
     n = Ptrcrd + Indcrd + Valcrd;
 
     for (i = 0; i < n; i++)
-      fgets(line, BUFSIZ, in_file);
+	if ( fgets(line, BUFSIZ, in_file) )
+	     IOHBTerminate("iohb.c: Error in input\n");
 
 /*  start  - number of initial aux vector entries to skip   */
 /*           to reach first  vector requested               */
@@ -635,14 +644,16 @@ int readHB_aux_double(const char* filename, const char AuxType, double b[])
     else start = (nvecs-1)*Nentries;
     stride = (nvecs-1)*Nentries;
 
-    fgets(line, BUFSIZ, in_file);
+    if ( fgets(line, BUFSIZ, in_file) )
+	IOHBTerminate("iohb.c: Error in input\n");
     linel= strchr(line,'\n')-line;
     col = 0;
 /*  Skip to initial offset */
 
     for (i=0;i<start;i++) {
        if ( col >=  ( maxcol<linel?maxcol:linel ) ) {
-           fgets(line, BUFSIZ, in_file);
+	   if ( fgets(line, BUFSIZ, in_file) )
+		IOHBTerminate("iohb.c: Error in input\n");
            linel= strchr(line,'\n')-line;
            col = 0;
        }
@@ -662,7 +673,8 @@ int readHB_aux_double(const char* filename, const char AuxType, double b[])
 
     for (i=0;i<Nentries;i++) {
        if ( col >= ( maxcol<linel?maxcol:linel ) ) {
-           fgets(line, BUFSIZ, in_file);
+	   if ( fgets(line, BUFSIZ, in_file) )
+		IOHBTerminate("iohb.c: Error in input\n");
            linel= strchr(line,'\n')-line;
            if (Rhsflag == 'D')  {
               while( strchr(line,'D') ) *strchr(line,'D') = 'E';
@@ -690,7 +702,8 @@ int readHB_aux_double(const char* filename, const char AuxType, double b[])
 
     for (i=0;i<stride;i++) {
        if ( col >= ( maxcol<linel?maxcol:linel ) ) {
-           fgets(line, BUFSIZ, in_file);
+	   if ( fgets(line, BUFSIZ, in_file) )
+		IOHBTerminate("iohb.c: Error in input\n");
            linel= strchr(line,'\n')-line;
            col = 0;
        }
@@ -975,7 +988,8 @@ int readHB_mat_char(const char* filename, int colptr[], int rowind[],
     count=0;
     for (i=0;i<Ptrcrd;i++)
     {
-       fgets(line, BUFSIZ, in_file);
+	if ( fgets(line, BUFSIZ, in_file) )
+	     IOHBTerminate("iohb.c: Error in input\n");
        if ( sscanf(line,"%*s") < 0 )
          IOHBTerminate("iohb.c: Null (or blank) line in pointer data region of HB file.\n");
        col =  0;
@@ -998,7 +1012,8 @@ int readHB_mat_char(const char* filename, int colptr[], int rowind[],
     count = 0;
     for (i=0;i<Indcrd;i++)
     {
-       fgets(line, BUFSIZ, in_file);
+	if ( fgets(line, BUFSIZ, in_file) )
+	     IOHBTerminate("iohb.c: Error in input\n");
        if ( sscanf(line,"%*s") < 0 )
          IOHBTerminate("iohb.c: Null (or blank) line in index data region of HB file.\n");
        col =  0;
@@ -1026,7 +1041,8 @@ int readHB_mat_char(const char* filename, int colptr[], int rowind[],
     count = 0;
     for (i=0;i<Valcrd;i++)
     {
-       fgets(line, BUFSIZ, in_file);
+	if ( fgets(line, BUFSIZ, in_file) )
+	     IOHBTerminate("iohb.c: Error in input\n");
        if ( sscanf(line,"%*s") < 0 )
          IOHBTerminate("iohb.c: Null (or blank) line in value data region of HB file.\n");
        if (Valflag == 'D') {
@@ -1190,7 +1206,8 @@ int readHB_aux_char(const char* filename, const char AuxType, char b[])
     n = Ptrcrd + Indcrd + Valcrd;
 
     for (i = 0; i < n; i++)
-      fgets(line, BUFSIZ, in_file);
+	if ( fgets(line, BUFSIZ, in_file) )
+	     IOHBTerminate("iohb.c: Error in input\n");
 
 /*  start  - number of initial aux vector entries to skip   */
 /*           to reach first  vector requested               */
@@ -1201,7 +1218,8 @@ int readHB_aux_char(const char* filename, const char AuxType, char b[])
     else start = (nvecs-1)*Nentries;
     stride = (nvecs-1)*Nentries;
 
-    fgets(line, BUFSIZ, in_file);
+    if ( fgets(line, BUFSIZ, in_file) )
+	IOHBTerminate("iohb.c: Error in input\n");
     linel= strchr(line,'\n')-line;
     if ( sscanf(line,"%*s") < 0 )
        IOHBTerminate("iohb.c: Null (or blank) line in auxillary vector data region of HB file.\n");
@@ -1211,7 +1229,8 @@ int readHB_aux_char(const char* filename, const char AuxType, char b[])
     for (i=0;i<start;i++) {
        col += Rhswidth;
        if ( col >= ( maxcol<linel?maxcol:linel ) ) {
-           fgets(line, BUFSIZ, in_file);
+	   if ( fgets(line, BUFSIZ, in_file) )
+		IOHBTerminate("iohb.c: Error in input\n");
            linel= strchr(line,'\n')-line;
        if ( sscanf(line,"%*s") < 0 )
        IOHBTerminate("iohb.c: Null (or blank) line in auxillary vector data region of HB file.\n");
@@ -1229,7 +1248,8 @@ int readHB_aux_char(const char* filename, const char AuxType, char b[])
 
     for (i=0;i<Nentries;i++) {
        if ( col >= ( maxcol<linel?maxcol:linel ) ) {
-           fgets(line, BUFSIZ, in_file);
+	   if ( fgets(line, BUFSIZ, in_file) ) 
+		IOHBTerminate("iohb.c: Error in input\n");
            linel= strchr(line,'\n')-line;
        if ( sscanf(line,"%*s") < 0 )
        IOHBTerminate("iohb.c: Null (or blank) line in auxillary vector data region of HB file.\n");
@@ -1260,7 +1280,8 @@ int readHB_aux_char(const char* filename, const char AuxType, char b[])
     for (i=0;i<stride;i++) {
        col += Rhswidth;
        if ( col >= ( maxcol<linel?maxcol:linel ) ) {
-           fgets(line, BUFSIZ, in_file);
+	   if ( fgets(line, BUFSIZ, in_file) )
+		IOHBTerminate("iohb.c: Error in input\n");
            linel= strchr(line,'\n')-line;
        if ( sscanf(line,"%*s") < 0 )
        IOHBTerminate("iohb.c: Null (or blank) line in auxillary vector data region of HB file.\n");
